@@ -16,7 +16,7 @@ class Speed():
 
     def inspect(self):
         if self.item_count == 0:
-            print "当前还没有还是计数"
+            print "当前还没有计数"
         else:
             c1 = self.item_count / (self.last_clock - self.born_clock).total_seconds()
             print "当前平均速度为1秒处理", c1, "个"
